//////////////////////////////////////////////////////////////////////////
// Module : IncSmad.c
// Usage  : Compile and link to any application that uses SmartAD.DLL.
//////////////////////////////////////////////////////////////////////////

#include <windows.h>

#include "IncSmad.h"

// Inline function used to get a DLL function address.
#define SETFPTR(PTR,FNAM)	if (!((int(__stdcall*)())PTR=GetProcAddress(hlib,FNAM))) return ERR_DLL_FUNC;

// Pointers to exported DLL functions.
long	SFPTR( InetAtoN )			( char * );
void	SFPTR( InetNtoA )			( char *, long );
long	SFPTR( SetBoardAttr )		( long, long, long );
void	SFPTR( ResetBoard )			( long );
void	SFPTR( SetIoNetTimeout )	( long, long );
void	SFPTR( SetHiSpeedMode )		( long );
void	SFPTR( SetReject50Hz )		( long );
long	SFPTR( GetFaultFlags )		( long );
long	SFPTR( GetBoardAdrs )		( long );
long	SFPTR( GetFWVersion )		( long );
long	SFPTR( GetIoNetVersion )	( long );
long	SFPTR( ChkIoNetReset )		( long );
void	SFPTR( SetFailMode )		( long, long, long );
void	SFPTR( SetFilter )			( long, long, long );
void	SFPTR( SetSensorType )		( long, long, long );
double	SFPTR( GetAmbientTemp )		( long, long );
void	SFPTR( GetAllSensors )		( long, double * );
double	SFPTR( GetSensorData )		( long, long );
void	SFPTR( SetGageZero )		( long, long );
void	SFPTR( SetGageSpan )		( long, long, long );
void	SFPTR( SetGageTare )		( long, long );
void	SFPTR( GetGageCal )			( long, long, double *, short * );
void	SFPTR( SetGageCal )			( long, long, double, short );

static HINSTANCE hlib;		// Handle to DLL.

static long OpenLink()
{
    // Dynamically link to the DLL.
	if ( !( hlib = LoadLibrary("SmartAD.dll") ) )
		return ERR_DLL_OPEN;

	// Get addresses of all DLL functions.
	SETFPTR( InetAtoN, "InetAtoN" );
	SETFPTR( InetNtoA, "InetNtoA" );
	SETFPTR( SetBoardAttr, "SetBoardAttr" );
	SETFPTR( ResetBoard, "ResetBoard" );
	SETFPTR( SetIoNetTimeout, "SetIoNetTimeout" );
	SETFPTR( SetHiSpeedMode, "SetHiSpeedMode" );
	SETFPTR( SetReject50Hz, "SetReject50Hz" );
	SETFPTR( GetFaultFlags, "GetFaultFlags" );
	SETFPTR( GetBoardAdrs, "GetBoardAdrs" );
	SETFPTR( GetFWVersion, "GetFWVersion" );
	SETFPTR( GetIoNetVersion, "GetIoNetVersion" );
	SETFPTR( ChkIoNetReset, "ChkIoNetReset" );
	SETFPTR( SetFailMode, "SetFailMode" );
	SETFPTR( SetFilter, "SetFilter" );
	SETFPTR( SetSensorType, "SetSensorType" );
	SETFPTR( GetAmbientTemp, "GetAmbientTemp" );
	SETFPTR( GetAllSensors, "GetAllSensors" );
	SETFPTR( GetSensorData, "GetSensorData" );
	SETFPTR( SetGageZero, "SetGageZero" );
	SETFPTR( SetGageSpan, "SetGageSpan" );
	SETFPTR( SetGageTare, "SetGageTare" );
	SETFPTR( GetGageCal, "GetGageCal" );
	SETFPTR( SetGageCal, "SetGageCal" );

	// Indicate DLL is linked and ready for access.
	return 0;
}

//////////////////////////////////////////////////////////////////////////
// Call LinkDLL() once before calling any SmartAD.DLL functions.
//////////////////////////////////////////////////////////////////////////

long LinkDLL()
{
	long ErrCode;

    // Dynamically link to the DLL.  Close link if error detected.
	if ( ErrCode = OpenLink() )
		UnLinkDLL();

	// Indicate whether DLL is linked and ready for access.
	return ErrCode;
}

/////////////////////////////////////////////////////////////////////////////
// Call UnLinkDLL() once after you are done calling SmartAD.DLL functions.
/////////////////////////////////////////////////////////////////////////////

void UnLinkDLL()
{
	// Unlink from DLL.
	if ( hlib != NULL )
		FreeLibrary( hlib );
}